<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\127\x6f\162\x64\x50\162\145\163\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\x4e\157\144\145\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\x74\x61\x74\151\x63"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\171\x74\150\157\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\122\x65\x76\145\x72\x73\x65\120\162\157\170\x79"; private const VARNISH_CACHE_SERVER = "\61\62\67\x2e\60\x2e\60\x2e\x31\72\66\x30\x38\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\x53\137\115\105\x54\110\x4f\104" => ["\166\x61\x6c\165\x65" => "\x64\x69\x72\145\x63\x74", "\x72\141\167" => false], "\x57\x50\137\x44\105\x42\125\x47\x5f\104\x49\123\120\x4c\101\131" => ["\x76\x61\154\x75\x65" => "\x66\x61\x6c\x73\x65", "\162\x61\x77" => true], "\127\x50\x5f\x44\x45\x42\x55\107\x5f\x4c\117\107" => ["\166\x61\154\x75\145" => "\x74\x72\x75\x65", "\162\x61\167" => true], "\x43\117\116\x43\101\x54\x45\x4e\101\124\x45\x5f\123\x43\122\x49\120\x54\123" => ["\166\x61\x6c\x75\145" => "\x66\x61\x6c\x73\145", "\x72\x61\x77" => true], "\x41\125\x54\117\x53\x41\x56\x45\137\111\x4e\x54\x45\122\x56\101\114" => ["\x76\x61\154\165\x65" => 600, "\162\141\x77" => true], "\x57\120\137\x50\x4f\x53\124\x5f\122\x45\x56\111\123\111\117\116\x53" => ["\166\141\154\165\145" => 5, "\162\141\167" => true], "\105\115\120\x54\131\x5f\124\122\101\x53\110\x5f\104\x41\x59\123" => ["\166\141\x6c\165\145" => 21, "\162\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\x57\120\x5f\101\114\114\117\127\x5f\115\x55\x4c\x54\111\x53\111\x54\105" => ["\166\141\x6c\165\x65" => "\x74\x72\x75\145", "\x72\x61\167" => true], "\x4d\125\x4c\x54\x49\x53\111\x54\x45" => ["\166\141\154\x75\145" => "\164\162\x75\145", "\162\141\x77" => true], "\123\x55\x42\104\x4f\x4d\101\111\x4e\x5f\x49\x4e\123\124\x41\x4c\114" => ["\x76\x61\x6c\165\145" => "\x66\x61\x6c\163\x65", "\162\x61\x77" => true], "\x44\x4f\x4d\101\x49\116\137\x43\x55\x52\x52\105\116\x54\x5f\123\x49\124\x45" => ["\166\141\x6c\165\145" => '', "\x72\141\x77" => false], "\x50\x41\124\x48\137\103\x55\x52\x52\x45\116\x54\x5f\x53\x49\124\x45" => ["\166\141\x6c\165\x65" => "\57", "\162\x61\167" => false], "\x53\111\124\x45\x5f\111\x44\x5f\x43\125\x52\122\x45\116\x54\137\123\x49\x54\x45" => ["\x76\x61\x6c\165\x65" => 1, "\x72\141\167" => true], "\x42\114\x4f\x47\x5f\111\104\137\103\x55\x52\x52\x45\116\x54\x5f\x53\111\124\105" => ["\x76\141\x6c\x75\x65" => 1, "\162\x61\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto c5098; Ff6fb: $this->databaseEntityManager = $databaseEntityManager; goto Fcfeb; Fa6ed: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto F6e94; F45fe: $this->certificateEntityManager = $certificateEntityManager; goto Ff6fb; aab21: parent::__construct($translator, $logger); goto f264a; c5098: $this->configManager = $configManager; goto Ea934; Ea934: $this->siteEntityManager = $siteEntityManager; goto F45fe; Da0c3: $this->databaseServerEntityManager = $databaseServerEntityManager; goto Fa6ed; cfc74: $this->validator = $validator; goto aab21; F6e94: $this->domainNameParser = $domainNameParser; goto cfc74; Fcfeb: $this->databaseUserEntityManager = $databaseUserEntityManager; goto Da0c3; f264a: } public function index(Request $request) : Response { goto ff158; fe869: $response = $this->render("\x46\x72\x6f\156\x74\145\156\144\57\123\151\164\x65\57\116\145\167\57\x69\156\144\145\170\56\x68\x74\x6d\154\56\164\x77\x69\147", ["\165\x73\145\x72" => $user]); goto db560; Ca01e: $user = $this->getUser(); goto fe869; b0bdf: if (true === $hasPermissions) { goto D955c; } goto ebb13; ebb13: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\151\164\145\x73")); goto e7b59; db560: f13eb: goto f1dae; E7ad4: D955c: goto Ca01e; ff158: $hasPermissions = $this->hasPermissions(); goto b0bdf; e7b59: goto f13eb; goto E7ad4; f1dae: return $response; goto dd0c2; dd0c2: } public function newPythonSite(Request $request) : Response { goto A262a; A262a: $hasPermissions = $this->hasPermissions(); goto C72db; E72d1: goto d3e4c; goto cc090; F43f1: if (!(true === $form->isSubmitted())) { goto fcc7b; } goto D6187; f238f: fcc7b: goto E5615; cd895: $form->handleRequest($request); goto F43f1; f9f26: $response = $this->render("\x46\x72\x6f\x6e\x74\x65\156\x64\x2f\x53\x69\164\x65\x2f\116\145\167\57\160\x79\164\x68\x6f\x6e\x2e\x68\x74\155\x6c\x2e\x74\x77\151\x67", ["\x75\x73\145\162" => $user, "\x66\157\162\x6d" => $form->createView(), "\x66\157\162\x6d\105\162\162\157\x72\x73" => $this->formErrors]); goto C132b; D6187: $response = $this->handleCreatePythonSiteForm($request, $form); goto f8362; Ef752: $pythonSettings = new PythonSettingsEntity(); goto Efa1f; c6782: return $response; goto Dc04c; c3182: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto e776d; } goto cd895; e19f3: D7e6f: goto f238f; Dad41: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\163\151\164\x65\x73")); goto E72d1; C132b: d3e4c: goto c6782; E5615: e776d: goto f9f26; Efa1f: $form = $this->createPythonSiteForm($pythonSettings); goto c3182; C72db: if (true === $hasPermissions) { goto F98bb; } goto Dad41; A2cde: $user = $this->getUser(); goto Ef752; fde9d: return $response; goto e19f3; cc090: F98bb: goto A2cde; f8362: if (!(false === is_null($response))) { goto D7e6f; } goto fde9d; Dc04c: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto f8b9b; D7d04: return $form; goto b35be; f8b9b: $form = $this->createForm("\x41\x70\x70\134\x46\x6f\x72\x6d\134\123\x69\x74\x65\116\145\x77\x50\171\164\x68\157\x6e\x54\x79\x70\x65", $pythonSettings, ["\x61\x63\x74\x69\x6f\x6e" => $this->generateUrl("\143\x6c\x70\x5f\x73\x69\164\x65\x5f\160\x79\164\x68\157\x6e\x5f\x6e\x65\x77"), "\x6d\145\164\x68\x6f\144" => "\x50\x4f\123\x54", "\141\x74\164\162" => ["\x69\x64" => "\156\x65\x77\55\160\x79\164\x68\157\x6e\55\163\151\164\x65\55\146\157\162\155"]]); goto bf405; bf405: $form->add("\x73\x75\142\x6d\151\164", SubmitType::class, ["\x61\x74\x74\x72" => ["\x63\154\141\x73\x73" => "\142\x74\156\x20\x62\x74\156\55\154\x67\x20\142\x74\156\x2d\x62\154\x75\145"], "\154\x61\x62\x65\x6c" => "\x43\x72\145\141\164\x65"]); goto D7d04; b35be: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto a4a87; a4a87: if (true === $form->isValid()) { goto fa4f1; } goto fe35a; fe35a: $this->formErrors = $this->getErrorMessages($form); goto F1d19; Bee31: fa4f1: goto dd765; Bd336: Df902: goto D2f6d; dd765: try { goto e7b21; B29d4: $siteUser = $form->get("\x73\x69\x74\x65\x55\x73\145\162")->getData(); goto D66c3; D1517: goto F7b46; goto F9927; F7568: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\163\151\x74\x65\163")); goto c5796; Bc2d8: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto Ed663; F769c: $user = $this->getUser(); goto cacca; B6249: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto A14e4; C78ea: $domainName = $form->get("\144\x6f\155\141\x69\x6e\x4e\141\155\145")->getData(); goto ab1ed; cbfeb: throw new \Exception(sprintf("\126\150\x6f\x73\x74\40\164\145\155\160\x6c\141\164\145\x20\42\45\x73\42\x20\x6e\x6f\164\40\x66\x6f\165\x6e\x64\56", $vhostTemplateName)); goto D1517; aa914: $port = $form->get("\x70\x6f\x72\164")->getData(); goto B29d4; ab1ed: $pythonVersion = $form->get("\x70\171\164\150\157\156\126\145\x72\x73\151\157\x6e")->getData(); goto aa914; Ed663: $session->getFlashBag()->set("\x73\x75\x63\143\x65\x73\163", $this->translator->trans("\123\x69\x74\145\40\x68\x61\x73\x20\x62\x65\145\156\40\143\162\145\141\x74\145\144\x2e")); goto F7568; cbf63: $eventData = ["\163\x69\164\x65" => $domainName, "\x73\151\164\145\125\163\x65\162" => $siteUser, "\x70\x79\x74\x68\x6f\156\126\x65\x72\x73\x69\x6f\156" => $pythonVersion, "\160\x6f\x72\x74" => $port]; goto Bc2d8; D66c3: $siteUserPassword = $form->get("\x73\x69\164\145\x55\x73\x65\162\120\141\x73\x73\x77\x6f\162\144")->getData(); goto B6249; F9927: D0c84: goto F769c; A14e4: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto cc9ff; cacca: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto cbf63; c5796: return $response; goto ebaff; cc9ff: if (false === is_null($vhostTemplateEntity)) { goto D0c84; } goto cbfeb; ebaff: F7b46: goto C770a; e7b21: $session = $request->getSession(); goto C78ea; C770a: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\147\x65\162", $this->translator->trans("\x41\156\x20\x65\x72\x72\x6f\162\x20\150\x61\163\40\x6f\143\x63\x75\162\x72\145\x64\x2c\x20\145\x72\162\157\162\40\x6d\x65\x73\163\141\147\x65\x3a\x20\45\x65\162\162\157\x72\115\145\x73\163\x61\x67\x65\x25", ["\x25\145\162\x72\x6f\x72\x4d\145\163\163\141\147\x65\45" => $e->getMessage()])); } goto Bd336; F1d19: goto Df902; goto Bee31; D2f6d: } public function newReverseProxy(Request $request) : Response { goto Aa1f4; Aa1f4: $hasPermissions = $this->hasPermissions(); goto cbccd; F8834: if (!(true === $form->isSubmitted())) { goto d647a; } goto Ae19c; Cdc97: $user = $this->getUser(); goto B1e05; D29dc: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\x69\x74\x65\x73")); goto fa7e2; D94b2: return $response; goto b4159; Dd0d6: ecba2: goto Ed7bd; Ae19c: $response = $this->handleReverseProxyForm($request, $form); goto d14ae; b4159: E8b93: goto Af04c; b8193: return $response; goto Dd56a; E85ee: $form->handleRequest($request); goto F8834; B60e5: B87e9: goto b8193; Ed7bd: $response = $this->render("\x46\162\x6f\x6e\164\145\156\144\x2f\x53\x69\x74\145\x2f\x4e\145\167\x2f\x72\145\x76\x65\162\x73\145\x2d\x70\x72\157\x78\171\56\x68\x74\155\154\56\164\167\x69\147", ["\x75\x73\145\x72" => $user, "\146\x6f\x72\155" => $form->createView(), "\146\157\x72\x6d\x45\x72\162\157\x72\x73" => $this->formErrors]); goto B60e5; D336c: bca4c: goto Cdc97; Af04c: d647a: goto Dd0d6; a5ae1: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto ecba2; } goto E85ee; cbccd: if (true === $hasPermissions) { goto bca4c; } goto D29dc; fa7e2: goto B87e9; goto D336c; B1e05: $form = $this->createReverseProxyForm(); goto a5ae1; d14ae: if (!(false === is_null($response))) { goto E8b93; } goto D94b2; Dd56a: } private function createReverseProxyForm() : Form { goto b27fa; b27fa: $form = $this->createForm("\101\160\x70\x5c\x46\x6f\x72\x6d\x5c\x53\151\164\145\116\x65\167\122\x65\x76\x65\162\163\145\120\162\x6f\x78\x79\124\x79\x70\x65", [], ["\x61\x63\x74\x69\x6f\x6e" => $this->generateUrl("\x63\x6c\160\137\x73\x69\x74\x65\137\x72\145\x76\x65\x72\x73\145\x5f\x70\x72\157\x78\171\x5f\x6e\145\167"), "\x6d\145\x74\x68\x6f\144" => "\x50\117\x53\124", "\141\164\164\162" => ["\151\x64" => "\156\145\x77\x2d\x72\145\166\x65\x72\163\145\x2d\x70\162\157\170\171\x2d\x66\157\162\155"]]); goto A5dcf; D9df2: return $form; goto a7769; A5dcf: $form->add("\x73\165\x62\155\151\x74", SubmitType::class, ["\x61\164\164\162" => ["\143\154\141\163\x73" => "\142\164\156\40\x62\x74\156\55\x6c\x67\40\142\x74\x6e\55\142\x6c\x75\x65"], "\x6c\141\142\145\154" => "\x43\162\145\x61\164\145"]); goto D9df2; a7769: } private function handleReverseProxyForm(Request $request, Form $form) { goto C109f; C109f: if (true === $form->isValid()) { goto Ed9a3; } goto Eb985; a615a: try { goto a9b73; b5519: Ba6c6: goto Db898; e0733: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto f46e1; c26f7: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto E5ef3; C2f90: $siteUser = $form->get("\163\x69\164\145\x55\163\145\162")->getData(); goto C3e6d; e9916: Fe6ab: goto E8891; C05a3: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\x69\164\145\163")); goto B44a1; f4dfe: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto E6960; B44a1: return $response; goto b5519; e4f94: $domainName = $form->get("\x64\x6f\155\x61\x69\156\x4e\x61\x6d\145")->getData(); goto C2f90; E6960: $session->getFlashBag()->set("\x73\165\143\x63\145\163\163", $this->translator->trans("\122\145\x76\x65\x72\x73\x65\x20\120\162\157\x78\171\40\150\141\163\40\142\145\145\x6e\x20\x63\162\x65\x61\x74\145\144\x2e")); goto C05a3; Ae747: goto Ba6c6; goto e9916; B364f: $reverseProxyUrl = $form->get("\162\145\x76\x65\162\163\145\120\162\157\170\x79\125\162\x6c")->getData(); goto Fe9a3; E8891: $user = $this->getUser(); goto e0733; Fe9a3: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto c26f7; E5ef3: if (false === is_null($vhostTemplateEntity)) { goto Fe6ab; } goto Bc937; f46e1: $eventData = ["\163\151\x74\145" => $domainName, "\x73\x69\164\x65\125\163\x65\x72" => $siteUser, "\162\145\166\x65\162\163\145\x50\162\157\x78\171\x55\x72\x6c" => $reverseProxyUrl]; goto f4dfe; C3e6d: $siteUserPassword = $form->get("\x73\x69\x74\x65\x55\163\x65\162\120\x61\163\x73\167\157\162\x64")->getData(); goto B364f; Bc937: throw new \Exception(sprintf("\126\x68\157\163\164\40\164\145\x6d\x70\x6c\141\164\x65\40\42\45\163\42\x20\x6e\x6f\x74\40\146\157\x75\156\144\x2e", $vhostTemplateName)); goto Ae747; a9b73: $session = $request->getSession(); goto e4f94; Db898: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\x67\x65\162", $this->translator->trans("\101\156\40\x65\x72\162\157\162\x20\150\141\x73\40\157\x63\143\165\162\162\x65\x64\54\40\145\x72\x72\157\x72\x20\155\x65\x73\163\141\147\x65\72\x20\45\145\x72\x72\157\162\115\x65\163\x73\141\147\x65\x25", ["\x25\145\162\x72\157\x72\115\145\163\x73\141\147\x65\x25" => $e->getMessage()])); } goto Fe87b; Eb985: $this->formErrors = $this->getErrorMessages($form); goto D9290; Fe87b: A7257: goto cb9a9; Af68b: Ed9a3: goto a615a; D9290: goto A7257; goto Af68b; cb9a9: } public function newNodejsSite(Request $request) : Response { goto F4912; Ddf40: if (!(true === $form->isSubmitted())) { goto aaa68; } goto f5ccc; fb646: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\x69\164\x65\x73")); goto c6a43; Bd12f: B965c: goto dc8f7; d1d70: A8ad5: goto d75c9; d75c9: $response = $this->render("\106\162\157\x6e\x74\145\156\144\x2f\123\151\164\x65\57\116\145\x77\x2f\156\x6f\x64\x65\x6a\x73\56\150\164\x6d\154\x2e\x74\167\x69\x67", ["\165\163\x65\x72" => $user, "\x66\157\162\155" => $form->createView(), "\146\x6f\162\x6d\105\162\162\157\162\163" => $this->formErrors]); goto F68b0; F4912: $hasPermissions = $this->hasPermissions(); goto b2535; Ce2b3: F38ac: goto bd545; A2e0c: if (!(false === is_null($response))) { goto B965c; } goto b8033; f32a4: $form = $this->createNodejsSiteForm($nodejsSettings); goto Ff2b6; bd545: $user = $this->getUser(); goto b2d6f; f5ccc: $response = $this->handleCreateNodejsSiteForm($request, $form); goto A2e0c; C3b6d: $form->handleRequest($request); goto Ddf40; dc8f7: aaa68: goto d1d70; b8033: return $response; goto Bd12f; c6a43: goto Be50c; goto Ce2b3; Ff2b6: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto A8ad5; } goto C3b6d; b2535: if (true === $hasPermissions) { goto F38ac; } goto fb646; F68b0: Be50c: goto ce915; ce915: return $response; goto f8ed9; b2d6f: $nodejsSettings = new NodejsSettingsEntity(); goto f32a4; f8ed9: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto C4c0a; C1f89: return $form; goto b6c6c; C4c0a: $form = $this->createForm("\x41\160\160\x5c\x46\157\x72\x6d\x5c\x53\x69\164\145\x4e\145\x77\x4e\157\144\x65\152\x73\124\171\160\x65", $nodejsSettings, ["\x61\143\x74\151\157\156" => $this->generateUrl("\143\154\x70\137\163\x69\x74\145\137\156\157\x64\145\x6a\x73\137\156\145\x77"), "\155\x65\x74\150\157\x64" => "\120\117\x53\124", "\x61\x74\x74\162" => ["\151\144" => "\x6e\x65\167\55\x6e\157\x64\x65\x6a\x73\55\163\x69\x74\145\55\146\157\x72\x6d"]]); goto bb9dd; bb9dd: $form->add("\163\165\x62\x6d\x69\x74", SubmitType::class, ["\x61\164\x74\x72" => ["\x63\154\x61\163\163" => "\142\164\x6e\40\x62\164\x6e\x2d\154\147\40\142\164\x6e\x2d\x62\154\x75\x65"], "\154\141\142\145\x6c" => "\103\x72\145\141\164\145"]); goto C1f89; b6c6c: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto F7500; a39ac: $this->formErrors = $this->getErrorMessages($form); goto edf9c; F7500: if (true === $form->isValid()) { goto c1c29; } goto a39ac; E0aa1: try { goto da370; Bdf28: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\x73\151\x74\x65\163")); goto Fbdbe; f1d82: if (false === is_null($vhostTemplateEntity)) { goto B44c7; } goto fea32; B60f1: $session->getFlashBag()->set("\163\165\143\143\145\x73\x73", $this->translator->trans("\x53\151\x74\x65\40\x68\141\x73\40\x62\145\x65\x6e\x20\x63\x72\145\x61\164\x65\144\56")); goto Bdf28; a76ac: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto f1d82; D3669: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto a76ac; Bbca5: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto B60f1; aaf09: goto cb7bc; goto d05fa; e45ca: $port = $form->get("\160\x6f\x72\x74")->getData(); goto ffa40; ffa40: $siteUser = $form->get("\x73\151\x74\x65\x55\163\145\162")->getData(); goto b55e6; fea32: throw new \Exception(sprintf("\126\150\x6f\x73\x74\40\x74\x65\x6d\x70\x6c\141\x74\x65\x20\x22\x25\163\x22\x20\x6e\x6f\x74\x20\x66\157\165\x6e\x64\x2e", $vhostTemplateName)); goto aaf09; b55e6: $siteUserPassword = $form->get("\163\151\x74\x65\x55\163\145\x72\120\x61\163\163\167\157\x72\144")->getData(); goto D3669; C7692: $user = $this->getUser(); goto A815b; Fbdbe: return $response; goto F52af; da370: $session = $request->getSession(); goto Eee45; b748e: $nodejsVersion = $form->get("\156\x6f\x64\x65\x6a\163\x56\x65\162\163\151\157\x6e")->getData(); goto e45ca; F187c: $eventData = ["\x73\151\164\145" => $domainName, "\163\151\164\x65\x55\163\x65\162" => $siteUser, "\156\x6f\144\x65\x6a\x73\x56\145\x72\163\x69\x6f\156" => $nodejsVersion, "\x70\x6f\x72\164" => $port]; goto Bbca5; Eee45: $domainName = $form->get("\144\157\155\141\x69\156\x4e\141\155\x65")->getData(); goto b748e; d05fa: B44c7: goto C7692; A815b: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto F187c; F52af: cb7bc: goto F49d9; F49d9: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\147\x65\162", $this->translator->trans("\101\156\40\x65\x72\x72\157\x72\x20\x68\x61\x73\x20\x6f\x63\x63\x75\x72\x72\x65\144\54\x20\x65\162\x72\157\x72\40\x6d\145\x73\x73\x61\147\x65\72\x20\x25\145\x72\x72\x6f\x72\x4d\145\163\163\x61\147\145\45", ["\45\x65\x72\x72\x6f\162\x4d\x65\x73\163\141\x67\x65\x25" => $e->getMessage()])); } goto C42f8; A0feb: c1c29: goto E0aa1; C42f8: F8e40: goto E9413; edf9c: goto F8e40; goto A0feb; E9413: } public function newStaticSite(Request $request) : Response { goto E6448; f3b1a: F0df5: goto f7e90; A98a9: $user = $this->getUser(); goto Fa321; F88b7: $response = $this->handleCreateStaticSiteForm($request, $form); goto Ac8cb; F1649: if (!(true === $form->isSubmitted())) { goto b8ff8; } goto F88b7; D60c7: f3583: goto af2d7; E66d6: if (true === $hasPermissions) { goto A4552; } goto c73a1; A8cd8: e7b61: goto d5118; Fa321: $form = $this->createStaticSiteForm(); goto C2c86; af2d7: b8ff8: goto f3b1a; E6448: $hasPermissions = $this->hasPermissions(); goto E66d6; c73a1: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\163\x69\164\145\163")); goto dfe98; f7e90: $response = $this->render("\x46\x72\157\x6e\x74\x65\x6e\x64\x2f\123\151\164\x65\57\116\x65\x77\57\x73\164\141\x74\151\143\x2e\x68\164\x6d\154\x2e\x74\x77\151\147", ["\165\163\145\x72" => $user, "\146\157\x72\x6d" => $form->createView(), "\146\x6f\162\x6d\x45\162\x72\157\x72\163" => $this->formErrors]); goto A8cd8; d5118: return $response; goto da93b; e32e8: $form->handleRequest($request); goto F1649; dfe98: goto e7b61; goto a9a54; d8c42: return $response; goto D60c7; C2c86: if (!(true === $request->isMethod("\120\x4f\123\x54"))) { goto F0df5; } goto e32e8; a9a54: A4552: goto A98a9; Ac8cb: if (!(false === is_null($response))) { goto f3583; } goto d8c42; da93b: } private function createStaticSiteForm() : Form { goto a1a62; E0fd9: return $form; goto ac0d3; d34c6: $form->add("\163\165\x62\x6d\x69\164", SubmitType::class, ["\x61\164\x74\x72" => ["\143\154\141\163\163" => "\x62\x74\156\40\142\164\x6e\x2d\154\x67\x20\142\164\156\55\x62\x6c\165\x65"], "\x6c\141\142\x65\x6c" => "\x43\x72\x65\x61\x74\145"]); goto E0fd9; a1a62: $form = $this->createForm("\101\x70\160\x5c\106\x6f\162\x6d\x5c\123\x69\x74\145\116\145\x77\x53\x74\x61\x74\x69\x63\x54\171\x70\145", [], ["\141\x63\164\151\x6f\x6e" => $this->generateUrl("\143\154\160\137\163\151\164\145\x5f\x73\x74\x61\164\x69\143\137\x6e\x65\167"), "\x6d\145\164\150\157\x64" => "\120\117\123\124", "\x61\x74\164\x72" => []]); goto d34c6; ac0d3: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto f8db5; Faca0: $this->formErrors = $this->getErrorMessages($form); goto E82fc; F09ce: f3f56: goto F2b86; c54af: df6ca: goto cdd55; f8db5: if (true === $form->isValid()) { goto df6ca; } goto Faca0; E82fc: goto f3f56; goto c54af; cdd55: try { goto be070; Edb2d: $domainName = $form->get("\x64\157\155\141\151\156\116\x61\155\145")->getData(); goto c80de; F7db8: $user = $this->getUser(); goto B34f1; eae1d: goto db639; goto b0715; A145e: throw new \Exception(sprintf("\126\150\x6f\163\x74\40\164\145\155\160\154\141\164\145\40\42\x25\163\42\40\x6e\157\164\x20\x66\157\x75\x6e\x64\56", $vhostTemplateName)); goto eae1d; B34f1: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto ed9b9; Dfff1: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto fa2a6; c3963: $siteUserPassword = $form->get("\x73\151\x74\145\125\x73\x65\162\x50\141\x73\x73\167\157\162\x64")->getData(); goto D576c; c80de: $siteUser = $form->get("\x73\151\164\145\x55\163\x65\162")->getData(); goto c3963; ed9b9: $eventData = ["\163\x69\x74\145" => $domainName, "\x73\151\x74\145\125\163\x65\x72" => $siteUser]; goto Dfff1; b6350: db639: goto Ade00; c9de9: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto B3e1e; be070: $session = $request->getSession(); goto Edb2d; D576c: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto c9de9; B3e1e: if (false === is_null($vhostTemplateEntity)) { goto E348d; } goto A145e; b0715: E348d: goto F7db8; Cb38d: return $response; goto b6350; D428f: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\x73\x69\x74\x65\163")); goto Cb38d; fa2a6: $session->getFlashBag()->set("\x73\165\x63\143\x65\163\x73", $this->translator->trans("\123\151\164\145\x20\x68\x61\163\40\x62\145\x65\x6e\x20\143\162\x65\141\164\145\144\x2e")); goto D428f; Ade00: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\147\x65\x72", $this->translator->trans("\101\x6e\40\145\162\162\157\162\x20\150\141\x73\x20\157\x63\143\x75\x72\162\145\x64\54\x20\145\x72\x72\x6f\x72\x20\155\145\163\163\x61\x67\x65\72\40\45\145\162\x72\157\162\x4d\145\x73\x73\x61\x67\145\x25", ["\45\x65\162\162\x6f\162\x4d\x65\163\163\141\x67\145\45" => $e->getMessage()])); } goto F09ce; F2b86: } public function newPhpSite(Request $request) : Response { goto Fe7f7; Bb3da: $form->handleRequest($request); goto f477f; a45e3: $user = $this->getUser(); goto bde4d; bde4d: $form = $this->createPhpSiteForm(); goto Cf725; De910: fbe15: goto a89ed; Cf725: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto Ecc79; } goto Bb3da; f7025: if (!(false === is_null($response))) { goto fbe15; } goto B4ca0; Ae698: goto B6e7e; goto ca26f; a89ed: F6036: goto d0c39; A18f1: B6e7e: goto B8e7f; B2f4d: $response = $this->render("\x46\x72\157\x6e\x74\x65\156\x64\x2f\123\x69\x74\x65\x2f\116\145\167\x2f\160\x68\x70\x2e\x68\164\x6d\x6c\x2e\x74\x77\151\147", ["\165\x73\x65\x72" => $user, "\146\x6f\x72\155" => $form->createView(), "\x66\x6f\x72\155\x45\x72\x72\x6f\x72\x73" => $this->formErrors]); goto A18f1; f477f: if (!(true === $form->isSubmitted())) { goto F6036; } goto F602a; d9285: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\163\x69\164\145\163")); goto Ae698; d0c39: Ecc79: goto B2f4d; ca26f: ff177: goto a45e3; B8e7f: return $response; goto eee8a; F602a: $response = $this->handleCreatePhpSiteForm($request, $form); goto f7025; Fe7f7: $hasPermissions = $this->hasPermissions(); goto C792c; B4ca0: return $response; goto De910; C792c: if (true === $hasPermissions) { goto ff177; } goto d9285; eee8a: } private function createPhpSiteForm() : Form { goto A9659; A9659: $form = $this->createForm("\x41\x70\160\134\106\157\162\x6d\134\x53\x69\x74\x65\x4e\x65\x77\120\150\x70\x54\171\x70\145", [], ["\x61\x63\164\x69\x6f\x6e" => $this->generateUrl("\143\154\160\137\163\151\x74\145\x5f\160\150\x70\x5f\x6e\145\x77"), "\x6d\x65\164\150\x6f\144" => "\120\x4f\x53\124", "\x61\164\x74\162" => []]); goto a33fc; a33fc: $form->add("\163\165\x62\155\151\164", SubmitType::class, ["\141\164\x74\x72" => ["\x63\154\x61\163\163" => "\x62\164\156\40\142\x74\x6e\55\x6c\147\x20\x62\164\x6e\55\x62\154\x75\x65"], "\154\x61\x62\x65\x6c" => "\103\162\145\141\x74\145"]); goto d286b; d286b: return $form; goto Eb43a; Eb43a: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto ac553; da075: $this->formErrors = $this->getErrorMessages($form); goto f867f; ac553: if (true === $form->isValid()) { goto e1d9f; } goto da075; efb0d: try { goto dc7fd; B2db6: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto A49c6; Ae068: $user = $this->getUser(); goto cfa13; cfa13: $rootDirectory = $domainName; goto E5d75; A49c6: $session->getFlashBag()->set("\163\x75\143\143\x65\163\x73", $this->translator->trans("\123\151\x74\x65\40\x68\141\163\x20\x62\x65\x65\156\40\143\x72\x65\x61\x74\145\x64\x2e")); goto a0c9d; c0bd7: $siteUser = $form->get("\163\x69\x74\x65\x55\163\x65\x72")->getData(); goto f5b40; a1cf6: $varnishCacheSettings = []; goto D4630; a0c9d: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\163\x69\x74\x65\x73")); goto c003a; bef4c: c33b2: goto a1cf6; f5b40: $siteUserPassword = $form->get("\x73\x69\x74\x65\x55\163\145\x72\120\141\x73\163\x77\157\x72\144")->getData(); goto eefae; b7622: dbbe1: goto Ab64b; d5f8a: $phpVersion = $form->get("\160\150\160\x56\x65\x72\x73\151\157\156")->getData(); goto c0bd7; B7fa1: $domainName = $form->get("\x64\157\155\141\151\x6e\116\141\155\145")->getData(); goto d5f8a; b0b80: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto da01c; D4630: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto a3e8b; } goto b0b80; dc7fd: $session = $request->getSession(); goto C9974; Dcd65: throw new \Exception(sprintf("\x56\x68\157\x73\164\x20\164\x65\x6d\160\x6c\141\164\x65\40\x22\x25\x73\42\x20\x6e\157\x74\x20\x66\157\165\156\144\56", $vhostTemplateName)); goto c96c2; c7824: $rootDirectory = sprintf("\x25\x73\57\45\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\x2f")); goto bef4c; eefae: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto a3242; c003a: return $response; goto b7622; c96c2: goto dbbe1; goto a08c9; C6aa2: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto c6625; a08c9: dd45c: goto Ae068; c6625: $eventData = ["\163\x69\164\145" => $domainName, "\x76\x68\157\163\164\124\x65\155\160\154\x61\164\145\116\141\155\145" => $vhostTemplateName, "\160\150\160\x56\x65\x72\x73\151\157\156" => $phpVersion, "\163\x69\x74\x65\x55\163\x65\x72" => $siteUser]; goto B2db6; E5d75: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto c33b2; } goto c7824; a3242: if (false === is_null($vhostTemplateEntity)) { goto dd45c; } goto Dcd65; da01c: a3e8b: goto C6aa2; C9974: $vhostTemplateName = $form->get("\x61\x70\160\x6c\151\143\x61\164\x69\x6f\156")->getData(); goto B7fa1; Ab64b: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\x67\x65\162", $this->translator->trans("\x41\156\40\145\x72\x72\157\x72\x20\150\141\163\40\157\x63\143\x75\162\162\x65\144\54\40\x65\x72\162\x6f\x72\40\x6d\x65\163\x73\x61\147\145\72\40\45\x65\x72\162\157\x72\115\145\x73\163\x61\x67\x65\x25", ["\x25\145\x72\162\x6f\162\x4d\x65\163\x73\141\x67\145\45" => $e->getMessage()])); } goto b472a; f867f: goto fb150; goto e82cc; e82cc: e1d9f: goto efb0d; b472a: fb150: goto bcb14; bcb14: } public function newWordPressSite(Request $request) : Response { goto A61d0; b31d5: if (true === $hasPermissions) { goto b8436; } goto cf7e5; A109d: d9941: goto E979f; B5df2: if (!(false === is_null($response))) { goto d9941; } goto f4dd1; F6261: $response = $this->render("\106\x72\157\156\x74\x65\156\144\x2f\123\x69\164\x65\x2f\x4e\x65\167\57\x77\x6f\162\144\x70\x72\x65\x73\x73\56\x68\x74\x6d\154\56\164\x77\x69\147", ["\x75\x73\145\162" => $user, "\146\157\x72\x6d" => $form->createView(), "\146\157\x72\155\105\x72\x72\x6f\x72\x73" => $this->formErrors]); goto ceda0; ceda0: Bfa0d: goto B779d; A61d0: $hasPermissions = $this->hasPermissions(); goto b31d5; C4fdb: if (!(true === $request->isMethod("\x50\x4f\123\x54"))) { goto Ac22f; } goto Bf805; f5b7a: goto Bfa0d; goto a8634; Dab7b: $user = $this->getUser(); goto F609b; B779d: return $response; goto E407b; f4dd1: return $response; goto A109d; cf7e5: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\x73\x69\x74\x65\163")); goto f5b7a; ebc5e: Ac22f: goto F6261; a8634: b8436: goto Dab7b; Bf805: $form->handleRequest($request); goto e53c1; E979f: Bcb4a: goto ebc5e; e53c1: if (!(true === $form->isSubmitted())) { goto Bcb4a; } goto E3c19; E3c19: $response = $this->handleCreateWordPressSiteForm($request, $form); goto B5df2; F609b: $form = $this->createWordPressSiteForm(); goto C4fdb; E407b: } private function createWordPressSiteForm() : Form { goto f0ce6; Ed274: $form->add("\x73\165\142\155\x69\164", SubmitType::class, ["\141\x74\x74\x72" => ["\x63\154\141\x73\163" => "\142\164\156\40\142\x74\x6e\x2d\x6c\147\x20\x62\164\156\55\x62\x6c\165\x65"], "\x6c\x61\142\145\x6c" => "\103\162\x65\141\164\145"]); goto b76c5; f0ce6: $form = $this->createForm("\101\x70\x70\x5c\106\x6f\162\155\134\123\151\164\x65\x4e\x65\167\x57\157\162\144\x50\162\x65\163\x73\124\x79\160\145", [], ["\141\x63\x74\151\157\156" => $this->generateUrl("\143\154\x70\x5f\163\x69\x74\145\137\x77\x6f\162\x64\160\162\145\x73\163\x5f\156\145\167"), "\155\x65\164\x68\x6f\x64" => "\120\117\x53\124", "\x61\x74\x74\162" => ["\x69\x64" => "\x6e\x65\x77\x2d\x77\x6f\x72\x64\160\162\145\163\163\55\x73\151\164\x65\55\x66\x6f\162\155"]]); goto Ed274; b76c5: return $form; goto Dc021; Dc021: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto D5df3; f3894: E38ff: goto A3c28; E3513: $this->formErrors = $this->getErrorMessages($form); goto a7676; A3c28: try { goto aa45a; aafa7: $databaseEntity->addUser($databaseUserEntity); goto aa4e8; cd0e1: return $response; goto A1adb; b2593: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto f9bf5; f842a: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto E1585; f045d: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto C3cd6; ca52d: if (!(false === is_null($siteEntity))) { goto e7ec6; } goto eeebc; bb383: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto a9571; C3cd6: $databaseUserEntity->setUserName($databaseUserName); goto ede4b; Bfcbe: $response = $this->redirect($this->generateUrl("\143\154\160\137\163\151\x74\x65\x5f\167\x6f\162\144\160\162\145\163\163\x5f\x69\x6e\163\x74\141\154\x6c\145\x64")); goto cd0e1; ba815: $siteCredentials[$this->translator->trans("\x44\x61\164\141\142\x61\163\145")] = [$this->translator->trans("\110\157\163\x74") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\x6f\x72\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\x61\164\141\142\x61\x73\x65\x20\x4e\141\x6d\145") => $databaseName, $this->translator->trans("\104\141\x74\141\x62\x61\163\145\40\125\163\145\x72\40\x4e\141\155\x65") => $databaseUserName, $this->translator->trans("\x44\x61\164\141\142\141\x73\x65\x20\125\163\x65\162\40\x50\141\x73\x73\167\157\162\144") => $databaseUserPassword]; goto Db299; a573e: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto C4b48; bef80: $databaseManager->createUser($databaseUserEntity); goto c35f7; De915: e7ec6: goto B3f60; B4625: $session = $request->getSession(); goto D0bc6; d4b7e: $generatedName = $this->generateNameFromDomainName($domainName); goto ac672; f9bf5: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto Fe05b; Bf4a5: $url = sprintf("\x68\x74\x74\x70\163\x3a\x2f\57\x25\163", $siteEntity->getDomainName()); goto Ae6e3; ac672: $siteUser = $form->get("\x73\x69\164\x65\x55\x73\x65\x72")->getData(); goto ba783; b1d92: $adminUserName = $form->get("\x61\144\155\x69\x6e\x55\x73\145\162\x4e\x61\155\x65")->getData(); goto e47cd; a9571: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto C78b6; aa45a: $user = $this->getUser(); goto B4625; ddc14: C8133: goto bb383; c198a: $adminEmail = $form->get("\x61\x64\x6d\151\x6e\105\x6d\141\x69\x6c")->getData(); goto F4b81; F9661: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto Ef6cf; f3d9b: $databaseEntity->setSite($siteEntity); goto f045d; ba783: $siteUserPassword = $form->get("\x73\x69\164\x65\x55\163\x65\162\120\141\163\163\x77\x6f\162\144")->getData(); goto b2593; Db299: $siteCredentials["\x57\157\162\144\120\162\145\x73\x73"] = [$this->translator->trans("\101\x64\155\x69\x6e\40\105\x2d\x4d\141\x69\154") => $adminEmail, $this->translator->trans("\x41\144\155\x69\156\x20\125\163\x65\x72\40\x4e\141\155\145") => $adminUserName, $this->translator->trans("\101\144\155\151\156\x20\120\141\163\163\167\x6f\162\x64") => $adminPassword, $this->translator->trans("\x41\x64\155\151\x6e\40\125\162\154") => sprintf("\150\x74\x74\160\x73\72\x2f\x2f\x25\x73\57\167\160\x2d\141\144\x6d\151\x6e\x2f", rtrim($domainName, "\57"))]; goto De915; C78b6: $instance = $request->attributes->get("\151\156\x73\x74\141\156\143\145"); goto f8f5c; B4aa7: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto Bfcbe; eeebc: $databaseName = $this->getUniqueDatabaseName($generatedName); goto F9661; C4b48: $databaseEntity->setName($databaseName); goto f3d9b; f8f5c: $siteCredentials = [$this->translator->trans("\123\x69\x74\x65") => [$this->translator->trans("\111\120\40\101\x64\144\162\x65\x73\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\104\x6f\x6d\x61\x69\156\40\116\x61\155\145") => sprintf("\x68\164\164\x70\163\72\57\x2f\45\163", $domainName), $this->translator->trans("\123\151\x74\x65\40\x55\x73\x65\162") => $siteUser, $this->translator->trans("\x50\141\x73\163\x77\x6f\162\x64") => $siteUserPassword]]; goto ca52d; Eee8a: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto ba815; d1193: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto C8133; } goto A29ab; Ba049: $databaseEntity = $this->databaseEntityManager->createEntity(); goto a573e; Ae6e3: $title = $form->get("\163\151\x74\145\x54\151\x74\x6c\145")->getData(); goto b1d92; ede4b: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto f3b7a; A29ab: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto ddc14; aa4e8: $siteEntity->addDatabase($databaseEntity); goto f842a; e47cd: $adminPassword = $form->get("\141\144\x6d\151\x6e\120\141\163\x73\167\x6f\x72\x64")->getData(); goto c198a; A076d: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Ba049; ed303: $databaseUserEntity->setDatabase($databaseEntity); goto aafa7; c35f7: $this->siteEntityManager->updateEntity($siteEntity); goto Eee8a; B3f60: $session->set("\x73\151\164\145\103\162\x65\144\x65\156\164\x69\x61\x6c\x73", $siteCredentials); goto bdb33; bdb33: $eventData = ["\163\x69\x74\x65" => $domainName, "\163\151\164\x65\125\163\145\162" => $siteUser]; goto B4aa7; D0bc6: $domainName = $form->get("\144\x6f\155\141\151\x6e\x4e\x61\155\145")->getData(); goto d4b7e; f3b7a: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto ed303; E1585: $databaseManager->createDatabase($databaseEntity); goto bef80; F4b81: $isMultiSite = $form->get("\x6d\165\x6c\164\151\x53\x69\x74\x65")->getData(); goto A076d; Fe05b: $varnishCacheSettings = []; goto d1193; Ef6cf: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto Bf4a5; A1adb: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\x65\x72", $this->translator->trans("\101\x6e\x20\145\x72\x72\157\x72\40\150\x61\163\x20\x6f\x63\143\x75\x72\162\x65\x64\x2c\x20\x65\162\162\x6f\x72\40\155\x65\163\x73\141\x67\x65\72\40\45\145\162\x72\157\x72\x4d\x65\x73\163\141\147\145\x25", ["\45\145\x72\162\x6f\162\x4d\x65\x73\x73\141\x67\145\45" => $e->getMessage()])); } goto f8303; a7676: goto bc5ce; goto f3894; D5df3: if (true === $form->isValid()) { goto E38ff; } goto E3513; f8303: bc5ce: goto c8c7b; c8c7b: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto ecae1; b6f71: Ef4cd: goto Fb1d2; D27b1: db1a0: goto b6f71; De36b: $this->wordPressMultiSiteConfigValues["\x44\117\115\x41\x49\x4e\x5f\x43\x55\122\x52\105\x4e\x54\x5f\123\111\x54\105"]["\166\x61\x6c\165\145"] = $siteEntity->getDomainName(); goto D9716; D9716: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\x6c\x75\x65"], $config["\162\x61\167"]); ce4c7: } goto D27b1; Eb093: $wordPressInstaller = new WordPressInstaller($siteEntity); goto d7de9; Caf02: if (!(true === $isMultiSite)) { goto Ef4cd; } goto De36b; fb2dc: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto Eb093; E761a: $databaseUserName = $databaseUserEntity->getUserName(); goto fb2dc; Ee8cc: cb8ac: goto Caf02; Ccf46: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto D9e32; df7f5: $databaseName = $databaseEntity->getName(); goto E761a; b1bfa: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto Ccf46; d7de9: $wordPressInstaller->downloadAndExtractLatestVersion(); goto b1bfa; ecae1: $databaseHost = sprintf("\45\x73\x3a\45\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto df7f5; D9e32: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\x6c\165\x65"], $config["\162\141\x77"]); A0b42: } goto Ee8cc; Fb1d2: $wordPressInstaller->resetPermissions(); goto Bddec; Bddec: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto f29a0; db090: goto F0fec; goto Dc0f9; B24d8: $certificateEntity->setSite($siteEntity); goto B524d; Ae1b4: $phpSiteCreator = new PhpSiteCreator($phpSite); goto d4f35; b04c9: beb1d: goto D01dc; fbf0c: $siteEntity->setRootDirectory($rootDirectory); goto a12fa; Be8c1: $phpSite->setSubdomain($subdomain); goto Cc25b; Fab0e: $siteEntity->setCertificate($certificateEntity); goto D61a8; A0ada: $phpSiteCreator->createPhpFpmPool(); goto c1d87; E4859: $constraintViolationList->addAll($siteConstraints); goto Fb85d; c1940: $phpSite->setVarnishCache(true); goto F1dcb; C5b02: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto c81b5; Acda8: if (!(false === empty($redirectionVhostTemplate))) { goto beb1d; } goto efd09; E5867: $siteEntity->setUserPassword($siteUserPassword); goto fbf0c; bd4b6: $phpSettingsEntity->setSite($siteEntity); goto B84c4; Fca76: $phpSiteCreator->createLogrotateFile(); goto cb6d0; eabf5: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto f51b8; } goto Cbfd5; F1dcb: $defaultVarnishCacheSettings = ["\145\156\141\x62\x6c\x65\x64" => false, "\x73\x65\162\166\x65\162" => self::VARNISH_CACHE_SERVER, "\143\141\143\150\145\124\x61\147\x50\x72\145\146\151\170" => substr(md5(time()), 0, 4)]; goto F0764; ac702: $siteEntity->setUser($siteUser); goto E5867; d53b2: $certificateEntity->setCsr($csr); goto C5b02; C8bdc: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Ee641; Cbfd5: $subjectAlternativeNames[] = $registrableDomain; goto a5820; B3dff: $this->siteEntityManager->updateEntity($siteEntity); goto faa47; d4f35: $phpSiteCreator->createUser(); goto Edf53; F68cf: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\57\56\56\57\56\x2e\x2f\x72\x65\x73\x6f\x75\162\x63\x65\x73\57\156\147\x69\x6e\170\57\166\150\157\163\164\137\x74\x65\155\160\x6c\141\x74\145\57\162\x65\144\x69\162\145\x63\164"); goto db090; b39e7: F0fec: goto a3a25; D7fc0: effc3: goto B737c; D01dc: a8512: goto f475c; e0f64: $siteEntity->setType(SiteEntity::TYPE_PHP); goto A76c0; Dc0f9: de0ad: goto fc4c5; a9c1b: $phpSettingsEntity = new PhpSettingsEntity(); goto c8a8c; D0128: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Ca5dc; Bf8d3: $phpSite->setDomainName($domainName); goto Ed4ec; Dbc58: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto c2f61; Fd189: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c09e2; ddccf: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto Bf8d3; d1c64: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto a9c22; Ed4ec: $phpSite->setRegistrableDomain($registrableDomain); goto Be8c1; f29a0: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto a24d4; C6076: $siteEntity->setVarnishCache(true); goto B7926; c8a8c: $siteEntity->setPhpSettings($phpSettingsEntity); goto e32dd; a08f1: $certificateEntity = $this->certificateEntityManager->createEntity(); goto B24d8; B737c: $phpSiteCreator->createNginxVhost(); goto Ddde8; B7926: B9f2c: goto Cc683; F0764: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto A876e; Ddde8: $phpSiteCreator->reloadNginxService(); goto ba098; Ffaf4: $phpSite->setPhpSettings($phpSettingsEntity); goto c6152; D2375: if (!(true === $varnishCache)) { goto effc3; } goto c1940; a9c22: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto B3dff; d3cd0: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto b1901; Abfb9: $phpSite->setUser($siteEntity->getUser()); goto ddccf; cb6d0: $phpSiteCreator->createIndexPhp(); goto b87ed; ae4a0: $siteEntity = $this->siteEntityManager->createEntity(); goto e0f64; e32dd: $phpSettingsEntity->setPhpVersion($phpVersion); goto bd4b6; D07bf: $vhostTemplate->resetProcessors(); goto D3d00; c2f61: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto fd741; } goto E96af; F71fe: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Edd79; cbffd: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Fd189; a5820: f51b8: goto cf0d2; c81b5: $certificateEntity->setCertificate($selfSignedCertificate); goto Fab0e; B0282: if (true === isset($_ENV["\101\120\x50\x5f\110\124\x54\x50\x33"]) && "\164\x72\x75\x65" === $_ENV["\101\120\120\x5f\110\x54\124\120\63"]) { goto de0ad; } goto F68cf; db764: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto D3298; c6152: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Ae1b4; Cc683: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto a8512; } goto B0282; b5006: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto D07bf; Ca5dc: $certificateEntity->setDefaultCertificate(true); goto f4093; D3d00: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto d3cd0; fc4c5: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\56\56\x2f\x2e\x2e\x2f\x72\145\163\157\165\162\x63\x65\163\57\156\x67\x69\156\170\x2f\166\x68\157\x73\164\137\x74\145\155\x70\x6c\141\164\145\x2f\162\145\x64\x69\x72\145\143\164\55\x68\164\x74\160\x33"); goto b39e7; a12fa: if (!(false === empty($varnishCache))) { goto B9f2c; } goto C6076; Cc25b: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto ead14; A79f2: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto D7fc0; f1572: $vhostTemplate->build(); goto d1c64; D3298: $subjectAlternativeNames = []; goto f0db0; E5c58: fd741: goto a08f1; b1901: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto f1572; D1e58: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto cbffd; F0a06: $vhostTemplate = new PhpVhostTemplate($phpSite); goto b5006; Fc422: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto F8c0e; E96af: $constraintViolationList = new ConstraintViolationList(); goto E4859; c09e2: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Fc422; a4c66: $subjectAlternativeNames[] = sprintf("\x77\167\x77\56\45\163", $domainName); goto D8c35; D8c35: afef2: goto eabf5; Fb85d: $constraintViolationList->addAll($phpSettingsConstraints); goto C8bdc; B84c4: $siteConstraints = $this->validator->validate($siteEntity); goto Dbc58; cf0d2: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F71fe; F8c0e: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ae4a0; faa47: return $siteEntity; goto f8bde; a3a25: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Acda8; Edd79: $csr = $csrGenerator->generate(); goto D0128; f475c: $siteEntity->setVhostTemplate($vhostTemplate); goto a9c1b; c1d87: $phpSiteCreator->reloadPhpFpmService(); goto D2375; a24d4: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\57"); goto D1e58; Edf53: $phpSiteCreator->createRootDirectory(); goto Fca76; B524d: $rsaKeyGenerator = new RsaKeyGenerator(); goto db764; ead14: $phpSite->setCertificate($certificateEntity); goto Ffaf4; f4093: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto d53b2; b87ed: $phpSiteCreator->createPrivateKeyAndCertificate(); goto A0ada; A876e: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto A79f2; efd09: $vhostTemplate = sprintf("\x25\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto b04c9; ba098: $phpSiteCreator->resetPermissions(); goto F0a06; A76c0: $siteEntity->setDomainName($domainName); goto ac702; f0db0: if (!(true === is_null($subdomain))) { goto afef2; } goto a4c66; Ee641: throw new \Exception(implode("\73\40", $errorMessages)); goto E5c58; D61a8: $phpSite = new PhpSite(); goto Abfb9; f8bde: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto d425e; A6796: E47cb: goto C2bdb; f8a7a: $nodejsSite->setCertificate($certificateEntity); goto C8caf; eaaf7: $nodejsSite->setDomainName($domainName); goto d9b8f; Ba8d1: $nodejsSettingsEntity->setPort($port); goto e1ddb; c5393: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto de525; d03e9: $subjectAlternativeNames = []; goto C743a; b5932: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D25dc; Bc9d4: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto cec66; E1eb9: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto D00f7; ea795: $vhostTemplate = sprintf("\x25\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto dc6aa; fa6a5: $subjectAlternativeNames[] = $registrableDomain; goto B1960; bfcd0: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto f8a7a; Afeac: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto D7e5b; Bfa7e: $nodejsSiteCreator->createRootDirectory(); goto be7d5; D2460: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto d526f; fa847: goto b0ffa; goto A6796; b9012: $siteEntity->setRootDirectory($domainName); goto A628a; D25dc: $siteEntity = $this->siteEntityManager->createEntity(); goto B3e02; dc6aa: Ef13f: goto c93df; Ba9d8: $nodejsSiteCreator->reloadNginxService(); goto ac61f; C25cf: $nodejsSite = new NodejsSite(); goto D682f; D5d16: $certificateEntity = $this->certificateEntityManager->createEntity(); goto B9cbf; C2bdb: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\56\56\57\56\56\x2f\x72\145\163\x6f\x75\x72\143\x65\163\x2f\156\147\151\x6e\170\57\x76\150\x6f\163\x74\x5f\x74\145\155\160\x6c\141\x74\x65\x2f\x72\x65\x64\x69\162\145\x63\164\x2d\150\x74\164\x70\63"); goto A8b9e; D2909: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\x2e\x2e\x2f\x2e\56\57\162\x65\x73\157\x75\x72\x63\x65\x73\57\156\147\151\156\170\x2f\x76\150\x6f\x73\164\x5f\x74\145\x6d\x70\154\141\x74\x65\57\162\145\x64\x69\162\145\143\x74"); goto fa847; Dae0b: throw new \Exception(implode("\x3b\40", $errorMessages)); goto D4c73; C8c55: $nodejsSiteCreator->createNvmDirectory(); goto da30c; E0499: if (true === isset($_ENV["\101\x50\x50\x5f\x48\x54\x54\120\63"]) && "\x74\x72\x75\x65" === $_ENV["\101\120\120\x5f\110\x54\x54\x50\63"]) { goto E47cb; } goto D2909; D4c73: A9770: goto D5d16; A628a: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto f50ac; } goto E0499; faac5: $this->siteEntityManager->updateEntity($siteEntity); goto Bc6e9; B1960: a2341: goto Ea1d5; B3f1f: $siteEntity->setCertificate($certificateEntity); goto C25cf; C0958: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto c5393; a4546: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto de1a8; da30c: $nodejsSiteCreator->installNodejs(); goto Cce2e; E4843: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto C7555; ccfe1: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ca15c; B9cbf: $certificateEntity->setSite($siteEntity); goto Edefa; ce4a4: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Fa957; Edefa: $rsaKeyGenerator = new RsaKeyGenerator(); goto Ca428; B33a2: $siteConstraints = $this->validator->validate($siteEntity); goto Ca2da; bc243: f0a76: goto b0add; A8925: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto c17b5; Ca428: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto d03e9; f37fc: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto E9039; c93ac: $constraintViolationList->addAll($siteConstraints); goto a6f79; d6fbe: $siteEntity->setVhostTemplate($vhostTemplate); goto A4072; b3f18: $certificateEntity->setDefaultCertificate(true); goto ccfe1; f13f5: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto eaaf7; C743a: if (!(true === is_null($subdomain))) { goto f0a76; } goto E04f1; A8b9e: b0ffa: goto E1eb9; C1a39: $siteEntity->setUserPassword($siteUserPassword); goto b9012; e1ddb: $nodejsSettingsEntity->setSite($siteEntity); goto B33a2; e9835: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto b5932; B2faa: $constraintViolationList = new ConstraintViolationList(); goto c93ac; C7555: $csr = $csrGenerator->generate(); goto aad9b; A4072: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto a4546; de1a8: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto Ba8d1; Cce2e: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto B8b9e; ac61f: $nodejsSiteCreator->resetPermissions(); goto D39b4; aad9b: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto b3f18; Bc6e9: return $siteEntity; goto F3622; D39b4: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto D2460; c17b5: $vhostTemplate->build(); goto Afeac; Ea1d5: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E4843; D00f7: if (!(false === empty($redirectionVhostTemplate))) { goto Ef13f; } goto ea795; a6f79: $constraintViolationList->addAll($nodejsSettingsConstraints); goto c0c89; Ff868: $siteEntity->setDomainName($domainName); goto dd99e; Ca15c: $certificateEntity->setCsr($csr); goto ce4a4; E9039: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto A8925; D7e5b: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto faac5; Caed9: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto A9770; } goto B2faa; Ca2da: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto Caed9; Fa957: $certificateEntity->setCertificate($selfSignedCertificate); goto B3f1f; d9b8f: $nodejsSite->setRegistrableDomain($registrableDomain); goto e1a74; E04f1: $subjectAlternativeNames[] = sprintf("\167\x77\x77\x2e\x25\x73", $domainName); goto bc243; cec66: $subdomain = $resolvedDomainName->subDomain()->toString(); goto b07d2; de525: $nodejsSiteCreator->createUser(); goto Bfa7e; c0c89: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Dae0b; C8caf: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto C0958; B8b9e: $nodejsSiteCreator->createNginxVhost(); goto Ba9d8; b07d2: $subdomain = false === empty($subdomain) ? $subdomain : null; goto e9835; b0add: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto a2341; } goto fa6a5; be7d5: $nodejsSiteCreator->createLogrotateFile(); goto C8c55; e1a74: $nodejsSite->setSubdomain($subdomain); goto bfcd0; D682f: $nodejsSite->setUser($siteEntity->getUser()); goto f13f5; dd99e: $siteEntity->setUser($siteUser); goto C1a39; d526f: $vhostTemplate->resetProcessors(); goto f37fc; d425e: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Bc9d4; B3e02: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto Ff868; c93df: f50ac: goto d6fbe; F3622: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ed1bd; b62d4: $pythonSite->setSubdomain($subdomain); goto C595a; e8586: $vhostTemplate->build(); goto C78d1; Bc8e4: A3597: goto A075e; b5763: $pythonSite->setUser($siteEntity->getUser()); goto A2215; d6c9c: $subjectAlternativeNames[] = sprintf("\x77\x77\167\x2e\x25\x73", $domainName); goto A22d6; e1574: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Ffc6a; A075e: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto adea4; F8075: $subdomain = false === empty($subdomain) ? $subdomain : null; goto c4828; d95bd: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto b1d27; ff548: $certificateEntity->setCsr($csr); goto b8d4b; a04d3: if (!(true === is_null($subdomain))) { goto be236; } goto d6c9c; a74e4: $siteEntity = $this->siteEntityManager->createEntity(); goto eec1b; Bd743: c14d1: goto cc5b0; B0302: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto a281d; b8d4b: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto E3af4; f7399: $pythonSiteCreator->createRootDirectory(); goto C2eeb; Fe70a: $csr = $csrGenerator->generate(); goto fe7c0; a2599: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto ff548; D1746: $pythonSite->setDomainName($domainName); goto bf059; C1419: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Bdf81; db571: goto A3597; goto Fbf83; A22d6: be236: goto Ef86b; C52fd: $pythonSiteCreator->createNginxVhost(); goto b4f6a; C2eeb: $pythonSiteCreator->createLogrotateFile(); goto aec4a; d0fd2: if (true === isset($_ENV["\x41\120\x50\137\x48\x54\x54\x50\63"]) && "\164\162\165\145" === $_ENV["\x41\x50\120\137\110\124\x54\x50\63"]) { goto ab11e; } goto Bd716; Ffc6a: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ec396; Ef86b: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto Cd7b2; } goto e14d1; Dd8de: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto a3314; eec1b: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto f62d9; b1a5a: $constraintViolationList->addAll($siteConstraints); goto D7de9; a3314: $subdomain = $resolvedDomainName->subDomain()->toString(); goto F8075; b4f6a: $pythonSiteCreator->reloadNginxService(); goto F89c1; E3af4: $certificateEntity->setCertificate($selfSignedCertificate); goto c700b; ca41a: $certificateEntity->setSite($siteEntity); goto d5e92; c700b: $siteEntity->setCertificate($certificateEntity); goto C9d20; F9b1f: $siteEntity->setPythonSettings($pythonSettingsEntity); goto Fcd65; c2c59: $pythonSite->setCertificate($certificateEntity); goto E9dc6; fe7c0: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto e9123; Fbf83: ab11e: goto a2c41; Bd716: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\56\56\57\x2e\x2e\x2f\162\145\x73\x6f\165\162\x63\145\x73\57\x6e\x67\151\156\170\57\166\x68\x6f\163\x74\137\164\x65\x6d\x70\154\x61\x74\145\57\x72\x65\144\x69\x72\x65\143\164"); goto db571; F3e00: $vhostTemplate->resetProcessors(); goto e1574; B1dbd: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Fe70a; E9dc6: $pythonSite->setPythonSettings($pythonSettingsEntity); goto d1aa0; C8d2f: Acf3e: goto Bd743; ec19e: $subjectAlternativeNames = []; goto a04d3; d1aa0: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto d95bd; a2c41: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\56\56\x2f\x2e\56\57\162\145\163\x6f\165\x72\143\145\x73\57\156\147\151\x6e\x78\x2f\166\x68\x6f\x73\164\x5f\164\145\x6d\160\x6c\x61\x74\x65\x2f\x72\145\x64\151\162\145\x63\x74\55\x68\164\164\x70\x33"); goto Bc8e4; ce7d8: $siteConstraints = $this->validator->validate($siteEntity); goto B0302; adea4: if (!(false === empty($redirectionVhostTemplate))) { goto Acf3e; } goto C30ff; c4b44: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto C52fd; D7de9: $constraintViolationList->addAll($pythonSettingsConstraints); goto C7f25; F89c1: $pythonSiteCreator->resetPermissions(); goto f6a4d; cc5b0: $siteEntity->setVhostTemplate($vhostTemplate); goto fa94a; b821e: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto A45a1; C6311: $pythonSettingsEntity->setPort($port); goto D69dd; a4e8e: $siteEntity->setUser($siteUser); goto f788a; C78d1: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Fd4d3; f62d9: $siteEntity->setDomainName($domainName); goto a4e8e; a281d: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto D40b8; } goto b50a5; C9d20: $pythonSite = new PythonSite(); goto b5763; f6a4d: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto dcc10; B0110: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto a74e4; b50a5: $constraintViolationList = new ConstraintViolationList(); goto b1a5a; C7f25: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto b821e; d4c48: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto c14d1; } goto d0fd2; Fae3d: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto ec19e; b1d27: $pythonSiteCreator->createUser(); goto f7399; e14d1: $subjectAlternativeNames[] = $registrableDomain; goto ccdde; C595a: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto c2c59; fa94a: $pythonSettingsEntity = new PythonSettingsEntity(); goto F9b1f; Bdf81: return $siteEntity; goto Cffb2; aec4a: $pythonSiteCreator->writePythonVersionFile(); goto c4b44; c4828: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto B0110; d5e92: $rsaKeyGenerator = new RsaKeyGenerator(); goto Fae3d; dcc10: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto F3e00; D69dd: $pythonSettingsEntity->setSite($siteEntity); goto ce7d8; Fe2d4: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto B1dbd; bf059: $pythonSite->setRegistrableDomain($registrableDomain); goto b62d4; ec396: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto e8586; A45a1: D40b8: goto Dbb1f; Ed1bd: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Dd8de; f788a: $siteEntity->setUserPassword($siteUserPassword); goto Ae3f1; ccdde: Cd7b2: goto Fe2d4; C30ff: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto C8d2f; Dbb1f: $certificateEntity = $this->certificateEntityManager->createEntity(); goto ca41a; e9123: $certificateEntity->setDefaultCertificate(true); goto a2599; Fcd65: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto C6311; Fd4d3: $this->siteEntityManager->updateEntity($siteEntity); goto C1419; A2215: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto D1746; Ae3f1: $siteEntity->setRootDirectory($domainName); goto d4c48; Cffb2: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto C0935; E6623: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto a2e84; a1fc0: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ddc3f; c0a5f: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto a1efc; Ffaad: $certificateEntity = $this->certificateEntityManager->createEntity(); goto b9944; ae605: $certificateEntity->setCertificate($selfSignedCertificate); goto bc30f; C0625: $vhostTemplate->build(); goto Ad2fb; B9c51: if (!(false === is_null($subdomain) && "\167\167\167" == $subdomain)) { goto B645f; } goto F834f; fac40: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto f03ad; c8a8a: if (!count($siteConstraints)) { goto f13f7; } goto a8180; ce0f8: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto bb6a8; C0935: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto b9119; B1713: $certificateEntity->setCsr($csr); goto C6d23; a8180: $constraintViolationList = new ConstraintViolationList(); goto E04af; E5497: aa2d6: goto Ab5ed; a72e4: return $siteEntity; goto e9b59; a2e84: $staticSiteCreator = new StaticSiteCreator($staticSite); goto e7910; A8e64: $rsaKeyGenerator = new RsaKeyGenerator(); goto ad245; ae29f: $vhostTemplate = new StaticVhostTemplate($staticSite); goto c0a5f; fcbec: $staticSite->setDomainName($domainName); goto a3c5b; e5aca: $staticSiteCreator->resetPermissions(); goto ae29f; a1efc: $vhostTemplate->resetProcessors(); goto Fcef1; a59ae: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Ad60b; ad245: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F787c; F3bee: $staticSiteCreator->createRootDirectory(); goto e62de; b9944: $certificateEntity->setSite($siteEntity); goto A8e64; C9270: $subjectAlternativeNames[] = sprintf("\167\x77\x77\x2e\x25\x73", $domainName); goto C8921; A74ea: $staticSiteCreator->createPrivateKeyAndCertificate(); goto Cf9e8; Cdc9b: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto F214b; Fbe83: $siteConstraints = $this->validator->validate($siteEntity); goto c8a8a; fbdd4: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto Fd356; adb95: $this->siteEntityManager->updateEntity($siteEntity); goto a72e4; a5e7f: f13f7: goto Ffaad; f03ad: b406c: goto E5497; eb768: $staticSite = new StaticSite(); goto f3dff; f1cdb: $staticSiteCreator->reloadNginxService(); goto e5aca; D996c: $staticSiteCreator->createIndexHtml(); goto A74ea; Bf628: if (true === isset($_ENV["\x41\120\120\x5f\110\x54\124\x50\63"]) && "\164\x72\x75\145" === $_ENV["\x41\x50\x50\137\110\x54\124\x50\63"]) { goto e7a3a; } goto b148d; b692a: $siteEntity->setRootDirectory($domainName); goto a2396; F787c: $subjectAlternativeNames = []; goto a1643; a2396: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto aa2d6; } goto Bf628; C8921: F1d26: goto B9c51; bc30f: $siteEntity->setCertificate($certificateEntity); goto eb768; b4b0c: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto Bbee5; a5970: $subdomain = $resolvedDomainName->subDomain()->toString(); goto b3124; c3529: $siteEntity->setUserPassword($siteUserPassword); goto b692a; Cf9e8: $staticSiteCreator->createNginxVhost(); goto f1cdb; a3c5b: $staticSite->setRegistrableDomain($registrableDomain); goto acdfc; E04af: $constraintViolationList->addAll($siteConstraints); goto C7393; e62de: $staticSiteCreator->createLogrotateFile(); goto D996c; acdfc: $staticSite->setSubdomain($subdomain); goto fbdd4; c0b27: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto e8c3c; A9713: B645f: goto D90f1; a3b2c: goto F4f1a; goto C4aca; e39bc: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto adb95; F834f: $subjectAlternativeNames[] = $registrableDomain; goto A9713; Ab5ed: $siteEntity->setVhostTemplate($vhostTemplate); goto Fbe83; fa779: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\x2f\x2e\x2e\57\56\56\57\162\145\x73\157\x75\x72\143\x65\163\x2f\x6e\x67\x69\x6e\170\x2f\166\150\157\163\164\x5f\x74\x65\155\160\x6c\x61\164\x65\x2f\x72\145\x64\x69\x72\145\143\x74\x2d\150\x74\164\x70\63"); goto b6f9e; Ad60b: $certificateEntity->setDefaultCertificate(true); goto D21ca; D21ca: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B1713; a1643: if (!(true === is_null($subdomain))) { goto F1d26; } goto C9270; e8c3c: $siteEntity->setDomainName($domainName); goto A7754; b3124: $subdomain = false === empty($subdomain) ? $subdomain : null; goto b4b0c; Fd356: $staticSite->setCertificate($certificateEntity); goto E6623; D90f1: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto ce0f8; ddc3f: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto C0625; C6d23: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto ae605; b9119: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto a5970; bb6a8: $csr = $csrGenerator->generate(); goto a59ae; Fcef1: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto a1fc0; b6f9e: F4f1a: goto Cdc9b; C7393: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto ad72e; e7910: $staticSiteCreator->createUser(); goto F3bee; ad72e: throw new \Exception(implode("\x3b\40", $errorMessages)); goto a5e7f; b148d: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\56\x2e\x2f\x2e\56\57\162\x65\163\157\x75\162\x63\x65\x73\57\x6e\x67\151\156\x78\57\x76\150\157\x73\x74\x5f\x74\145\155\x70\154\141\164\x65\57\x72\x65\144\x69\162\x65\143\x74"); goto a3b2c; Bbee5: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto b4826; C4aca: e7a3a: goto fa779; F214b: if (!(false === empty($redirectionVhostTemplate))) { goto b406c; } goto fac40; Ad2fb: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto e39bc; C1f00: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto fcbec; A7754: $siteEntity->setUser($siteUser); goto c3529; b4826: $siteEntity = $this->siteEntityManager->createEntity(); goto c0b27; f3dff: $staticSite->setUser($siteEntity->getUser()); goto C1f00; e9b59: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto abb9f; c9dfe: $certificateEntity->setCsr($csr); goto Cff38; ae647: F863d: goto d04ee; B37d8: if (true === isset($_ENV["\101\x50\x50\x5f\110\x54\124\x50\63"]) && "\164\162\x75\x65" === $_ENV["\101\x50\x50\x5f\x48\x54\124\x50\63"]) { goto b4811; } goto Be5bb; d2c1d: $constraintViolationList = new ConstraintViolationList(); goto C8134; Eb3aa: $siteConstraints = $this->validator->validate($siteEntity); goto E8290; E8316: if (!(false === empty($redirectionVhostTemplate))) { goto E12ef; } goto A53ac; e6902: $certificateEntity->setCertificate($selfSignedCertificate); goto ccb5c; e8b35: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto A9bed; A19f3: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto C5200; Be5bb: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\56\56\57\56\x2e\57\162\145\x73\157\165\x72\143\145\x73\57\156\x67\x69\x6e\170\x2f\166\x68\x6f\163\164\x5f\164\145\155\x70\x6c\141\x74\x65\x2f\x72\145\x64\x69\x72\145\143\164"); goto D752b; abb9f: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ebde9; B0e73: if (!(false === is_null($subdomain) && "\x77\167\x77" == $subdomain)) { goto Ce422; } goto Fc691; a150b: b4811: goto Fe79b; B7407: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto a6b6e; Fe79b: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\56\x2e\x2f\56\x2e\x2f\162\145\163\157\165\162\143\145\x73\x2f\x6e\147\151\x6e\x78\57\x76\150\x6f\x73\164\137\164\x65\155\x70\154\141\x74\x65\57\162\x65\144\x69\162\x65\x63\x74\55\150\164\x74\160\63"); goto D6325; fb934: $siteEntity = $this->siteEntityManager->createEntity(); goto e1641; C4757: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto e3f08; b02d3: $reverseProxySite = new ReverseProxySite(); goto A4d0a; ff77b: if (!(true === is_null($subdomain))) { goto b24d3; } goto ca9e7; ba88b: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto B6759; a6b6e: $reversProxySiteCreator->createNginxVhost(); goto c058c; b3e6f: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto e114a; C087b: $reversProxySiteCreator->createLogrotateFile(); goto B7407; d8c2e: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto Df6e4; B6759: $certificateEntity->setDefaultCertificate(true); goto Bbc80; B031e: $vhostTemplate->resetProcessors(); goto C4757; Dd3d0: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto F3bc0; Dd543: Fac37: goto d44e6; ccb5c: $siteEntity->setCertificate($certificateEntity); goto b02d3; A53ac: $vhostTemplate = sprintf("\45\163\45\163", $redirectionVhostTemplate, $vhostTemplate); goto dc476; F9165: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto E8316; Ad615: $this->siteEntityManager->updateEntity($siteEntity); goto ec678; A4d0a: $reverseProxySite->setUser($siteEntity->getUser()); goto d426b; Ebde9: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b71d3; F420c: Ce422: goto D14e5; Cf1cb: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto cc181; E51bb: $reversProxySiteCreator->createRootDirectory(); goto C087b; F3534: $vhostTemplate->build(); goto E3c82; dc476: E12ef: goto Dd543; Bbc80: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto c9dfe; e114a: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Ff51e; D752b: goto cbcff; goto a150b; b83ba: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Ad615; Dedd4: $siteEntity->setUserPassword($siteUserPassword); goto cca4c; E3c82: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto b83ba; d426b: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto Dcff1; a7521: $reverseProxySite->setRegistrableDomain($registrableDomain); goto D68c1; Df0c4: $reversProxySiteCreator->createUser(); goto E51bb; A9bed: $csr = $csrGenerator->generate(); goto ba88b; c4f79: throw new \Exception(implode("\73\40", $errorMessages)); goto ae647; B4c96: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto c4f79; d04ee: $certificateEntity = $this->certificateEntityManager->createEntity(); goto df010; df010: $certificateEntity->setSite($siteEntity); goto cee89; ec678: return $siteEntity; goto Df323; Df6e4: $reverseProxySite->setCertificate($certificateEntity); goto b3e6f; E8290: if (!count($siteConstraints)) { goto F863d; } goto d2c1d; Dcff1: $reverseProxySite->setDomainName($domainName); goto a7521; cee89: $rsaKeyGenerator = new RsaKeyGenerator(); goto d4f57; Fc691: $subjectAlternativeNames[] = $registrableDomain; goto F420c; F0c1f: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A19f3; d4f57: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto B4265; B4265: $subjectAlternativeNames = []; goto ff77b; C5200: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto fb934; ca9e7: $subjectAlternativeNames[] = sprintf("\x77\167\x77\x2e\45\x73", $domainName); goto E9ca9; D6325: cbcff: goto F9165; Cff38: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto e6902; E9ca9: b24d3: goto B0e73; c058c: $reversProxySiteCreator->reloadNginxService(); goto bc120; D14e5: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto e8b35; F3bc0: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto Fac37; } goto B37d8; ca8f0: $siteEntity->setUser($siteUser); goto Dedd4; cc181: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto B031e; e3f08: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto f2902; bc120: $reversProxySiteCreator->resetPermissions(); goto Cf1cb; d44e6: $siteEntity->setVhostTemplate($vhostTemplate); goto Eb3aa; b71d3: $subdomain = $resolvedDomainName->subDomain()->toString(); goto F0c1f; a6909: $siteEntity->setDomainName($domainName); goto ca8f0; f2902: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto F3534; e1641: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto a6909; C8134: $constraintViolationList->addAll($siteConstraints); goto B4c96; cca4c: $siteEntity->setRootDirectory($domainName); goto Dd3d0; D68c1: $reverseProxySite->setSubdomain($subdomain); goto d8c2e; Ff51e: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto Df0c4; Df323: } public function installedWordPressSite(Request $request) : Response { goto Ca6e5; F2d8d: $response = $this->render("\x46\162\157\x6e\x74\x65\x6e\x64\57\x53\x69\164\x65\57\x4e\x65\167\x2f\x77\x6f\162\144\x70\162\145\163\x73\x2d\x69\156\163\x74\x61\x6c\x6c\145\x64\56\x68\164\x6d\154\x2e\x74\167\151\147", ["\163\151\164\145\103\162\145\x64\x65\x6e\164\x69\x61\x6c\163" => $siteCredentials]); goto F5222; E0664: goto bc955; goto E8552; F5222: return $response; goto e4a35; D04b6: $response = $this->redirect($this->generateUrl("\143\154\160\137\163\x69\x74\x65\x73")); goto E0664; e1a72: return $response; goto A57d6; Ca6e5: $session = $request->getSession(); goto E02e0; Dfbe2: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto F2d8d; E8552: A96c5: goto Dfbe2; E02e0: $siteCredentials = $session->get("\x73\x69\164\145\x43\162\x65\x64\x65\x6e\164\151\x61\x6c\163"); goto D27ea; D27ea: if (false === empty($siteCredentials)) { goto A96c5; } goto D04b6; e4a35: bc955: goto e1a72; A57d6: } private function renderSiteCredentials(array $siteCredentials) : string { goto c035a; c035a: $renderedCredentials = ''; goto Fe529; f7623: Aa068: goto C0a4f; Fe529: foreach ($siteCredentials as $section => $sectionData) { goto e69a6; d6a8a: $renderedCredentials .= "\55\55\55\x2d\55\55\x2d\55\x2d\x2d\55\x2d\55\x2d\x2d\x2d\55\x2d\x2d\x2d\x2d\55\x2d\x2d\x2d\x2d\x2d\x2d\55\x2d\55\55\55\x2d\55\55\x2d\55\55\55\55\55\x2d\x2d\55\x2d\x2d\55\x2d\55\x2d\55\55\55" . PHP_EOL; goto E3da6; b82e7: fc689: goto c42b1; c42b1: $renderedCredentials .= PHP_EOL; goto a3e62; a3e62: f374d: goto B99c2; E3da6: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\45\163\72\x20\45\x73", $key, $value) . PHP_EOL; b9106: } goto b82e7; e69a6: $renderedCredentials .= $section . PHP_EOL; goto d6a8a; B99c2: } goto f7623; C0a4f: return $renderedCredentials; goto c6f9f; c6f9f: } private function getVhostTemplateEntity(string $name) : mixed { goto A88eb; E0963: throw new \Exception($this->translator->trans("\126\x68\157\163\x74\x20\124\145\155\160\154\x61\164\145\40\x25\x76\x68\157\163\164\x54\145\x6d\x70\154\x61\x74\145\x25\40\x64\x6f\145\x73\x20\x6e\x6f\x74\x20\145\170\151\163\164\56", ["\x25\x76\150\x6f\163\x74\124\145\x6d\160\154\141\164\x65\45" => $name])); goto fec51; A88eb: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto D2680; D2680: if (!(true === is_null($vhostTemplateEntity))) { goto Ef34c; } goto E0963; F1c66: return $vhostTemplateEntity; goto fe631; fec51: Ef34c: goto F1c66; fe631: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto D7ed4; D8976: D9b94: goto decec; decec: return $errorMessages; goto C18da; ea83e: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\163\x3a\x20\45\x73", $constraint->getPropertyPath(), $constraint->getMessage()); c8dce: } goto D8976; D7ed4: $errorMessages = []; goto ea83e; C18da: } private function generateNameFromDomainName(string $domainName) : string { goto be541; E98c7: if ("\167\167\167" == $subdomain) { goto F32bd; } goto d4ec6; d7678: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto e44ed; d1b89: goto e09ac; goto D6922; a11be: return $name; goto C9d5f; c9b70: $name = $explodedRegistrableDomain[0] ?? ''; goto C1372; e44ed: $subdomain = $resolvedDomainName->subDomain()->toString(); goto B7486; Ff289: if (!(false === empty($subdomain))) { goto Fde92; } goto Eb42b; C1372: e09ac: goto a11be; d4ec6: $name = $explodedRegistrableDomain[0] ?? ''; goto Ff289; A41fd: Fde92: goto d1b89; Eb42b: $explodedSubdomain = explode("\x2e", $subdomain); goto D52d1; D52d1: $name = sprintf("\x25\x73\55\45\x73", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto A41fd; B7486: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto E98c7; be541: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto d7678; D6922: F32bd: goto c9b70; C9d5f: } private function getUniqueDatabaseName(string $databaseName) : string { goto ff62c; e28c9: $uniqueDatabaseName = sprintf("\45\x73\55\144\x62", $uniqueDatabaseName); goto eb4a4; F1d17: if (!(0 < $i)) { goto aa300; } goto abf91; b1aad: f3be7: goto Ecb6a; abf91: $uniqueDatabaseName = sprintf("\x25\x73\55\x25\163", $databaseName, $i); goto A40dc; C04b1: D383c: goto F1d17; A40dc: aa300: goto Bd307; eb4a4: Dc4d1: goto E110a; E0926: $databases = $databaseConnection->getDatabases(); goto C04b1; b45ad: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto d9329; Bd307: $databaseExists = in_array($uniqueDatabaseName, $databases); goto c0dc0; c0dc0: $i++; goto d3a88; d3a88: if (true === $databaseExists) { goto D383c; } goto b1aad; d9329: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto E0926; ff62c: $uniqueDatabaseName = $databaseName; goto Aa37d; Ecb6a: return $uniqueDatabaseName; goto E60ec; E110a: $i = 0; goto b45ad; Aa37d: if (!(strlen($uniqueDatabaseName) <= 3)) { goto Dc4d1; } goto e28c9; E60ec: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto Cec93; D99cc: if (false === is_null($databaseUserEntity)) { goto Da44b; } goto c1e27; D569a: $uniqueDatabaseUserName = sprintf("\x25\163\55\x64\142", $uniqueDatabaseUserName); goto Cc26b; Ba4b8: $uniqueDatabaseUserName = sprintf("\45\x73\x2d\x25\163", $databaseUserName, $i); goto ae0d6; E7ffb: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto b03a4; } goto D569a; ea9fe: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto a938d; Cec93: $uniqueDatabaseUserName = $databaseUserName; goto E7ffb; D7bc1: if (!(0 < $i)) { goto F96ec; } goto Ba4b8; D9174: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto afbf1; ae0d6: F96ec: goto ea9fe; e96ec: Da44b: goto D7bc1; Cc26b: b03a4: goto Dcc26; a938d: $i++; goto D99cc; c1e27: A9a68: goto D9174; Dcc26: $i = 0; goto e96ec; afbf1: return $uniqueDatabaseUserName; goto F4af0; F4af0: } private function hasPermissions() : bool { goto Ac8f2; Ac8f2: $user = $this->getUser(); goto F7e09; ad082: return true; goto C421b; F7e09: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto a1394; } goto ad082; f2876: return false; goto cc79b; C421b: a1394: goto f2876; cc79b: } }
